==> scipion-em-continuousflex-0.1.tar.gz: scipion-em-continuousflex-0.1/continuousflex/protocols/__init__.py <==
# **************************************************************************
# *
# * Authors: 
# * J.M. De la Rosa Trevin (jmdelarosa@cnb.csic.es)
# * Slavica Jonic (slavica.jonic@upmc.fr)
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************
from .protocol_nma import XmippProtNMA
from .protocol_nma_alignment import XmippProtAlignmentNMA
from .protocol_nma_base import NMA_CUTOFF_ABS, NMA_CUTOFF_REL
#from .protocol_nma_choose import XmippProtNMAChoose
from .protocol_nma_dimred import XmippProtDimredNMA
from .protocol_batch_cluster import BatchProtNMACluster
from .protocol_structure_mapping import XmippProtStructureMapping

==> scipion-em-continuousflex-0.6.tar.gz: scipion-em-continuousflex-0.6/continuousflex/protocols/__init__.py <==
# **************************************************************************
# *
# * Authors: 
# * J.M. De la Rosa Trevin (jmdelarosa@cnb.csic.es)
# * Slavica Jonic (slavica.jonic@upmc.fr)
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************
from .protocol_nma import FlexProtNMA
from .protocol_nma_alignment import FlexProtAlignmentNMA
from .protocol_nma_base import NMA_CUTOFF_ABS, NMA_CUTOFF_REL
#from .protocol_nma_choose import XmippProtNMAChoose
from .protocol_nma_dimred import FlexProtDimredNMA
from .protocol_batch_cluster import FlexBatchProtNMACluster
from .protocol_structure_mapping import FlexProtStructureMapping
from .data import *
from .pdb import *
